# -*- coding: utf-8 -*-
from setuphelpers import *
import platform
import bs4 as BeautifulSoup
import shutil

"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()


"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = 'Osiris-Mac'

def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob('*%s*.dmg' % bin_contains)[0]
    # Installing the package
    print("Installing: %s" % control.package)
    install_dmg(bin_name)

def uninstall():
    #shutil.rmtree('/Applications/System Applications Folder.app')
    shutil.rmtree('/Applications/User Applications Folder.app')
    app_name = glob.glob('/Applications/*Osiris*.app')[0]
    shutil.rmtree(app_name)
    




def update_package():
    # Declaring local variables
    result = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    bin_name_sub = bin_contains + '-%s.dmg'
    url = 'https://www.ncbi.nlm.nih.gov/osiris/download/'
    if control.architecture == 'x64':
        arch = '64bit'
    else:
        arch = '32bit'

    # Getting latest version from official sources
    print("URL used is: %s" % url)
    for bs_search in bs_find_all(url, 'a',  proxies=proxies):
        if bin_contains in bs_search['href'] and '.dmg' in bs_search['href']:
            version = bs_search['href'].split('-')[-1].rsplit('.',1)[-2]
            latest_bin = bs_search['href'].split('/')[-1]
            url_dl =  bs_search['href']
            break

    print("Latest %s version is: %s" % (app_name, version))
    print("Download url is: %s" % url_dl)

    # Downloading latest binaries
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(url_dl, latest_bin, proxies=proxies)


    # Changing version of the package
    if Version(version) > Version(control.get_software_version()):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        result = True
    control.version = '%s-%s' % (Version(version), control.version.split('-', 1)[-1])
    #control.set_software_version(Version(version))
    control.save_control_to_wapt()

    # Deleting outdated binaries
    remove_outdated_binaries(version,list_extensions=['msi'])

    # Validating or not update-package-sources
    return result


